@@ -3,13 +3,12 @@ package Term::Highlight;
 require Exporter;
 
 use strict;
-use sort 'stable';
 
 our @ISA = qw( Exporter );
 
-our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns GetPatterns Process );
+our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns Process );
 
-our $VERSION = "1.8";
+our $VERSION = "1.3";
 
 
 sub new
@@ -33,16 +32,16 @@ sub ByPositions
 }
 
 
-#sub PrintPosition
-#{
-    #my ( $position, $header ) = @_;
-    ##start position, length, start(1) or end(0) of pattern,
-    ##pattern number, pattern, fg color id,
-    ##bold, bg color id
-    #print "$header: $$position[ 0 ], $$position[ 1 ], $$position[ 2 ],
-                    #$$position[ 3 ], ${ $$position[ 4 ] }->[ 0 ], ${ $$position[ 4 ] }->[ 1 ],
-                    #${ $$position[ 4 ] }->[ 2 ], ${ $$position[ 4 ] }->[ 3 ]\n";
-#}
+sub PrintPosition
+{
+    my ( $position, $header ) = @_;
+    #start position, length, start(1) or end(0) of pattern,
+    #pattern number, pattern, fg color id,
+    #bold, bg color id
+    print "$header: $$position[ 0 ], $$position[ 1 ], $$position[ 2 ],
+                    $$position[ 3 ], ${ $$position[ 4 ] }->[ 0 ], ${ $$position[ 4 ] }->[ 1 ],
+                    ${ $$position[ 4 ] }->[ 2 ], ${ $$position[ 4 ] }->[ 3 ]\n";
+}
 
 
 sub LoadArgs
@@ -54,7 +53,7 @@ sub LoadArgs
     {
         SWITCH_ARGS:
         {
-            if ( $arg =~ /^-(.+)/ )
+            if ( $arg =~ /^-(.*)/ )
             {
                 SWITCH_OPTS:
                 {
@@ -67,13 +66,13 @@ sub LoadArgs
                     if ( $1 eq "ra" )   { $fgcolor = undef; $bold = undef; $bgcolor = undef;
                                           last SWITCH_OPTS }
                     if ( $1 eq "b" )    { $bold = 1; last SWITCH_OPTS }
-                    if ( ( my $orig = $1 ) =~ /^\d{1,3}(?=\.1$)/ )
+                    if ( ( my $orig = $1 ) =~ /\d{1,3}(?=\.1)/ )
                                         { $bgcolor = substr $orig, $-[ 0 ], $+[ 0 ] - $-[ 0 ];
                                           last SWITCH_OPTS }
-                    if ( ( my $orig = $1 ) =~ /^\d{1,3}(?=\.0$|$)/ )
+                    if ( ( my $orig = $1 ) =~ /\d{1,3}(?=\.0)?/ )
                                         { $fgcolor = substr $orig, $-[ 0 ], $+[ 0 ] - $-[ 0 ];
                                           last SWITCH_OPTS }
-                    print __PACKAGE__, " : WARNING: unknown option '$arg'\n";
+                    print __PACKAGE__, " : Warning: unknown option '-$1'\n";
                 }
                 $lastPatternOmitted = 1;
                 last SWITCH_ARGS;
@@ -92,7 +91,7 @@ sub LoadArgs
     }
     #push undefined pattern for last options not followed by any pattern
     #which will apply for the whole string
-    unshift @{ $self->{ Patterns } }, [ undef, $fgcolor, $bold ] if $lastPatternOmitted;
+    push @{ $self->{ Patterns } }, [ undef, $fgcolor, $bold ] if $lastPatternOmitted;
 }
 
 
@@ -110,41 +109,27 @@ sub ClearPatterns
 }
 
 
-sub GetPatterns
-{
-    my $self = shift;
-    $self->{ Patterns };
-}
-
-
 sub FindPositionsOfTags
 {
     my ( $positions, $patterns, $string_ref ) = @_;
     my $result = 0;
     for ( my $i = 0; $i < @$patterns; ++$i )
     {
-        if ( defined $$patterns[ $i ][ 0 ] )
+        unless ( defined $$patterns[ $i ][ 0 ] )
         {
-            while ( $$string_ref =~ /$$patterns[ $i ][ 0 ]/g )
-            {
-                my $length = $+[ 0 ] - $-[ 0 ];
-                next if $length == 0;
-                push @$positions, ( [ $-[ 0 ], $length, 1, $i, \$$patterns[ $i ] ],
-                                    [ $+[ 0 ], $length, 0, $i, \$$patterns[ $i ] ] );
-                ++$result;
-            }
+            my $length = length $$string_ref;
+            push @$positions, ( [ 0, $length, 1, $i, \$$patterns[ $i ] ],
+                                [ $length, $length, 0, $i, \$$patterns[ $i ] ] );
+            ++$result;
         }
         else
         {
-            #always mark the line matched in this case, perhaps with no tags
-            ++$result;
-            my $length = length $$string_ref;
-            next if $length == 0;
-            #trailing new lines cause problems: put the color tag before them
-            --$length if substr( $$string_ref, -1 ) eq "\n";
-            next if $length == 0;
-            push @$positions, ( [ 0, $length, 1, $i, \$$patterns[ $i ] ],
-                                [ $length, $length, 0, $i, \$$patterns[ $i ] ] );
+            while ( $$string_ref =~ /$$patterns[ $i ][ 0 ]/g )
+            {
+                push @$positions, ( [ $-[ 0 ], $+[ 0 ] - $-[ 0 ], 1, $i, \$$patterns[ $i ] ],
+                                    [ $+[ 0 ], $+[ 0 ] - $-[ 0 ], 0, $i, \$$patterns[ $i ] ] );
+                ++$result;
+            }
         }
     }
     $result;
@@ -209,7 +194,11 @@ sub InsertTags
                 if ( $tagtype eq "term" )
                 {
                     use integer;
-                    my $bold = ${ $$position[ 4 ] }->[ 2 ] || 22;
+                    # BEWARE: documentation says that escape sequence 2;
+                    # is not supported everywhere. Setting -ra with escape sequence 2;
+                    # makes wrong foreground color on libvte-based terminals whereas letting
+                    # it be undef may not reset bold typeface in some cases
+                    my $bold = ${ $$position[ 4 ] }->[ 2 ] || 2;
                     # BEWARE: documentation says that escape sequences 39; and 49;
                     # are not supported everywhere
                     my ( $fgcolor, $bgcolor )= ( "39", "49" );
@@ -222,7 +211,7 @@ sub InsertTags
                                      ${ $$position[ 4 ] }->[ 3 ];
                         $bold = ${ $$position[ 4 ] }->[ 1 ] / 8 if defined
                                      ${ $$position[ 4 ] }->[ 1 ];
-                        $bold ||= ${ $$position[ 4 ] }->[ 2 ] || 22;
+                        $bold ||= ${ $$position[ 4 ] }->[ 2 ] || 2;
                     }
                     #color id in [16..255]
                     else
@@ -278,7 +267,7 @@ sub Process
     #replace all but the last ending tags from @Positions by one-before-the-last starting tag
     #(crucial for terminal color escape sequences algorithm)
     RearrangePositionsOfTags( \@Positions, \@{ $self->{ Patterns } } );
-
+    
     #insert tags into current line
     InsertTags( \@Positions, $String_ref, $$self{ tagtype } );
 
@@ -288,7 +277,7 @@ sub Process
 
 =head1 NAME
 
-Term::Highlight - Perl module to highlight regexp patterns on terminals
+Term::Highlight - perl module to highlight regexp patterns on terminals
 
 =head1 SYNOPSIS
 
@@ -298,11 +287,9 @@ Term::Highlight - Perl module to highlight regexp patterns on terminals
 
 =item $obj = Term::Highlight->new( tagtype => $TAGTYPE );
 
-=item $obj->LoadPatterns( \@ptns );
-
 =item $obj->LoadArgs( \@args );
 
-=item $obj->GetPatterns( );
+=item $obj->LoadPatterns( \@ptns );
 
 =item $obj->ClearPatterns( );
 
@@ -312,14 +299,14 @@ Term::Highlight - Perl module to highlight regexp patterns on terminals
 
 Currently C<term> and C<term-debug> tagtypes are supported.
 If tagtype is C<term> then boundaries of found patterns will be enclosed in
-ANSI terminal color escape sequence tags, if tagtype is C<term-debug> then they
-will be marked by special symbolic sequences.
+terminal color escape sequence tags, if tagtype is C<term-debug> then they
+will be marked by symbolic sequences.
 
 =head1 DESCRIPTION
 
-Term::Highlight is a Perl module aimed to support highlighting of regexp
-patterns on color terminals.
-It supports 256 color terminals a well as older 8 color terminals.
+Term::Highlight is perl module aimed to support highlighting of patterns
+on color terminals. It supports 256 color terminals and older
+8 color terminals.
 
 =head1 EXPORTS
 
@@ -327,30 +314,24 @@ It supports 256 color terminals a well as older 8 color terminals.
 
 =item B<LoadPatterns>
 
-expects a reference to an array of references to arrays of type
-[ $pattern, $fg, $bold, $bg ].
-Loads patterns to be processed.
-
-=item B<LoadArgs>
-
-expects an array of references to strings.
-Loads patterns to be processed.
-This is just a convenient version of C<LoadPatterns>.
-Example of array to be loaded: [ "-46", "-25.1", "-i", "\bw.*?\b", "-100" ].
-
-=item B<GetPatterns>
-
-returns a reference to the loaded patterns.
+expects reference to array of references to arrays of structure
+[ $pattern, $fg, $bold, $bg ]. Loads patterns to be processed.
 
 =item B<ClearPatterns>
 
-clears the loaded patterns.
+clears loaded patterns.
+
+=item B<LoadArgs>
+
+expects array of references to strings. Loads patterns to be processed.
+This is just a convenient version of C<LoadPatterns>.
+Example of array to be loaded:
+[ "-46", "-25.1", "-i", "\bw.*?\b", "-100" ].
 
 =item B<Process>
 
-expects a reference to a string.
-Makes substitution of color tags inside the string.
-Returns count of found matches.
+expects reference to string. Makes substitution of color tags inside the
+string. Returns count of found matches.
 
 =back
 
@@ -364,7 +345,7 @@ A. Radkov, E<lt>alexey.radkov@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2016 by A. Radkov.
+Copyright (C) 2008 by A. Radkov.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
